==> velait_api-0.0.3.tar.gz: velait_api-0.0.3/velait/velait_fastapi/api/middleware.py <==
from fastapi import Request
from starlette.middleware.base import BaseHTTPMiddleware
from assimilator.core.database.exceptions import InvalidQueryError

from velait.velait_fastapi.api.responses import APIResponse, ResponseErrorItem
from velait.velait_fastapi.api.users.exceptions import NotAuthorizedError
from velait.velait_fastapi.api.users.permissions import NoPermissionError
from velait.velait_fastapi.database.exceptions import NotFoundError, AlreadyDeletedError, InvalidSearchData


class ExceptionHandlerMiddleware(BaseHTTPMiddleware):
    async def dispatch(self, request: Request, call_next):
        try:
            response = await call_next(request)
        except (NotFoundError, AlreadyDeletedError) as exc:
            return APIResponse(status_code=404, errors=[
                ResponseErrorItem(name="obj", description="Not found")
            ])
        except InvalidQueryError as exc:
            return APIResponse(status_code=400, errors=[
                ResponseErrorItem(name="obj", description="Not found")
            ])
        except NotAuthorizedError as exc:
            return APIResponse(status_code=403, errors=[
                ResponseErrorItem(name="auth", description="Not authorized")
            ])
        except NoPermissionError:
            return APIResponse(status_code=403, errors=[
                ResponseErrorItem(name="auth", description="Not enough permissions"),
            ])
        except InvalidSearchData as exc:
            return APIResponse(
                status_code=400,
                errors=[
                    ResponseErrorItem(name=error['name'], description=error['description'])
                    for error in exc.errors
                ]
            )

        return response

==> velait_api-0.0.7.tar.gz: velait_api-0.0.7/velait/velait_fastapi/api/middleware.py <==
from fastapi import Request
from starlette.middleware.base import BaseHTTPMiddleware
from assimilator.core.database.exceptions import InvalidQueryError, NotFoundError

from velait.velait_fastapi.api.responses import APIResponse, ResponseErrorItem
from velait.velait_fastapi.api.users.exceptions import NotAuthorizedError
from velait.velait_fastapi.api.users.permissions import NoPermissionError
from velait.velait_fastapi.database.exceptions import AlreadyDeletedError, InvalidSearchData


class ExceptionHandlerMiddleware(BaseHTTPMiddleware):
    async def dispatch(self, request: Request, call_next):
        try:
            response = await call_next(request)
        except (NotFoundError, AlreadyDeletedError) as exc:
            return APIResponse(status_code=404, errors=[
                ResponseErrorItem(name="obj", description="Not found")
            ])
        except InvalidQueryError as exc:
            return APIResponse(status_code=400, errors=[
                ResponseErrorItem(name="obj", description="Not found")
            ])
        except NotAuthorizedError as exc:
            return APIResponse(status_code=403, errors=[
                ResponseErrorItem(name="auth", description="Not authorized")
            ])
        except NoPermissionError:
            return APIResponse(status_code=403, errors=[
                ResponseErrorItem(name="auth", description="Not enough permissions"),
            ])
        except InvalidSearchData as exc:
            return APIResponse(
                status_code=400,
                errors=[
                    ResponseErrorItem(name=error['name'], description=error['description'])
                    for error in exc.errors
                ]
            )

        return response


__all__ = [
    'ExceptionHandlerMiddleware',
]
